@@ -809,7 +809,7 @@ class SessionStore(object):
         return True
 
     def delete(self):
-        """remove session id file (e.g. when it only contains an invalid session id
+        """remove session id file (e.g. when it only contains an invalid session id)
 
         Raises:
             NotImplementedError
@@ -845,7 +845,7 @@ class SessionStore(object):
             >>> oct(384)
             '0600' Python 2
             >>> oct(384)
-            '0o600'  Python 3  """
+            '0o600' Python 3  """
             return False
 
         return True
@@ -873,6 +873,8 @@ class Client(object):
         auth (tuple): e.g. ("user", "pass") - see requests documentation ("auth") for details
         client_auth_cert (str): file path containing both certificate and key (unencrypted) in
             PEM format to use for TLS client authentication (passed to requests as "cert")
+        customer_user (bool): flag to indicate that the username is for a "CustomerUser"
+           (defaults to False)
         user_agent (str): optional HTTP UserAgent string
         webservice_path (str): OTRS REST Web Service Path part - defaults to
             "/otrs/nph-genericinterface.pl/Webservice/"
@@ -894,6 +896,7 @@ class Client(object):
                  ca_cert_bundle=None,
                  auth=None,
                  client_auth_cert=None,
+                 customer_user=False,
                  user_agent=None,
                  webservice_path="/otrs/nph-genericinterface.pl/Webservice/"):
 
@@ -962,6 +965,8 @@ class Client(object):
         self.auth = auth
         self.client_auth_cert = client_auth_cert
 
+        self.customer_user = customer_user
+
         self.user_agent = user_agent
 
         # credentials
@@ -984,7 +989,7 @@ class Client(object):
         """check whether session_id is currently valid
 
         Args:
-            session_id (str): optional If set overrides the self.session_id
+            session_id (str): optional if set overrides the self.session_id
 
         Raises:
             ArgumentMissingError: if session_id is not set
@@ -1021,10 +1026,16 @@ class Client(object):
         """
         self.operation = "SessionCreate"
 
-        payload = {
-            "UserLogin": self.username,
-            "Password": self.password
-        }
+        if self.customer_user:
+            payload = {
+                "CustomerUserLogin": self.username,
+                "Password": self.password
+            }
+        else:
+            payload = {
+                "UserLogin": self.username,
+                "Password": self.password
+            }
 
         if not self._parse_and_validate_response(self._send_request(payload)):
             return False
@@ -1059,7 +1070,8 @@ class Client(object):
                              "from ({0})".format(self.session_id_store.file_path))
                     return True
             except APIError:
-                """most likely invalid session_id so pass. Remove clear session_id_store.."""
+                """Most likely invalid session_id. Remove it from session_id_store."""
+                pass
 
         # got no (valid) session_id; clean store
         self.session_id_store.write("")
@@ -1963,7 +1975,7 @@ class Client(object):
         Raises:
             OTRSAPIError
             NotImplementedError
-            ResponseJSONParseError
+            ResponseParseError
 
         Returns:
             **bool**: **True** if successful
